@@ -1,6 +1,6 @@
 # vim: set fileencoding=utf-8 :
 # GNU Solfege - free ear training software
-# Copyright (C) 2009, 2010  Tom Cato Amundsen
+# Copyright (C) 2009, 2010, 2011  Tom Cato Amundsen
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,16 +17,23 @@
 
 from __future__ import absolute_import
 
+import locale
 import logging
+import sys
 
 import gtk
 
 import solfege
-from solfege import cfg
 from solfege import frontpage
 from solfege import gu
 from solfege import lessonfile
 
+def decode_entry_string(s):
+    if sys.platform == 'win32':
+        return s.decode("mbcs", "replace")
+    return s.decode(locale.getpreferredencoding(), "decode")
+
+
 class SelectWinBase(gtk.ScrolledWindow):
     """
     Base class for the classes that display the front page and the
@@ -122,7 +129,7 @@ class SelectWinBase(gtk.ScrolledWindow):
         # ubuntu 10.04 and +4 on MS Windows XP.
         h = self.g_box.size_request()[1] + 4
         if h > gtk.gdk.screen_height() * 0.8:
-            h = gtk.gdk.screen_height() *0.8
+            h = int(gtk.gdk.screen_height() *0.8)
         self.set_size_request(w, h if h > self.m_min_height else self.m_min_height)
         # Then we check if we have to move the app window higher up on the
         # screen so that the whole window is visible.
@@ -166,7 +173,8 @@ class ExerciseView(SelectWinBase):
         if len(page[0]) > 0 and isinstance(page[0][0], frontpage.LinkList):
             count = 0
             for p in page[0]:
-                count += len(p[0])
+                if len(p):
+                    count += len(p[0])
             if count > 80:
                 do_sg = False
         for column in page:
@@ -294,7 +302,7 @@ class ExerciseView(SelectWinBase):
         only_tests - True if we should only return exercises that have
                      tests
         """
-        logging.debug("search: '%s'" % substring)
+        logging.debug("search: '%s'", substring)
         match_func = {
             False: lambda filename: substring in _no_xgettext(lessonfile.infocache.get(filename, 'title')).lower(),
             True: lambda filename: substring in lessonfile.infocache.get(filename, 'title').lower()
@@ -332,8 +340,8 @@ class FrontPage(ExerciseView):
                            show_topics)
         self.g_searchentry.grab_focus()
     def on_search(self, *button):
-        search_for = self.g_searchentry.get_text().lower()
-        logging.debug("FrontPage.on_search '%s'" % search_for)
+        search_for = decode_entry_string(self.g_searchentry.get_text().lower())
+        logging.debug(u"FrontPage.on_search '%s'", search_for)
         page = self._search(search_for, False, False)
         page_C = self._search(search_for, True, False)
         page_C.m_name = _('Search untranslated lesson titles')
@@ -350,7 +358,7 @@ class TestsView(ExerciseView):
         self._display_data(data, True, is_search_result, show_topics)
         self.g_searchentry.grab_focus()
     def on_search(self, *button):
-        search_for = self.g_searchentry.get_text().lower()
+        search_for = decode_entry_string(self.g_searchentry.get_text().lower())
         page = self._search(search_for, False, True)
         page_C = self._search(search_for, True, True)
         page_C.m_name = u'Search exercises without translating them'
@@ -377,9 +385,9 @@ class SearchView(ExerciseView):
         self._display_data(data)
         self.g_searchentry.grab_focus()
     def on_search(self, *button):
-        search_for = self.g_searchentry.get_text().lower()
+        search_for = decode_entry_string(self.g_searchentry.get_text().lower())
         lessonfile.infocache.update_modified_files()
-        self.display_search_result(self.g_searchentry.get_text(), [
+        self.display_search_result(decode_entry_string(self.g_searchentry.get_text()), [
             filename for filename in lessonfile.infocache._data
             if search_for in _(lessonfile.infocache.get(filename, 'title')).lower()
         ], [
