@@ -1,5 +1,5 @@
 # GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2006, 2007, 2008  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2006, 2007, 2008, 2011  Tom Cato Amundsen
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -207,7 +207,7 @@ class PianoOctaveWithAccelName(PianoKeyboard):
         if event.button == 3:
             utils.play_note(4, midi_int)
         elif event.button == 1:
-            self.m_callback(mpd.int_to_notename(midi_int))
+            self.m_callback(mpd.int_to_octave_notename(midi_int))
 
 
 class IntervalPianoWidget(PianoKeyboard):
@@ -234,7 +234,7 @@ class IntervalButtonsWidget(gtk.Table, cfg.ConfigUtils):
         self.new_int_button(_("Minor Third"),   3, 0, 1, 4, 6)
         self.new_int_button(_("Major Third"),    4, 0, 1, 6, 8)
         self.new_int_button(_("Perfect Fourth"),    5, 1, 2, 0, 2)
-        self.new_int_button(_("Diminished Fifth"),    6, 1, 2, 2, 4)
+        self.new_int_button(_("Tritone"),    6, 1, 2, 2, 4)
         self.new_int_button(_("Perfect Fifth"),    7, 1, 2, 4, 6)
         self.new_int_button(_("Minor Sixth"),  8, 1, 2, 6, 8)
         self.new_int_button(_("Major Sixth"),   9, 2, 3, 0, 2)
@@ -243,8 +243,8 @@ class IntervalButtonsWidget(gtk.Table, cfg.ConfigUtils):
         self.new_int_button(_("Perfect Octave"),   12, 2, 3, 6, 8)
         self.new_int_button(_("Minor Ninth"),  13, 3, 4, 0, 2)
         self.new_int_button(_("Major Ninth"),   14, 3, 4, 2, 4)
-        self.new_int_button(_("Minor Decim"), 15, 3, 4, 4, 6)
-        self.new_int_button(_("Major Decim"),  16, 3, 4, 6, 8)
+        self.new_int_button(_("Minor Tenth"), 15, 3, 4, 4, 6)
+        self.new_int_button(_("Major Tenth"),  16, 3, 4, 6, 8)
         self.m_lowest_tone = mpd.LOWEST_NOTENAME
         self.m_highest_tone = mpd.HIGHEST_NOTENAME
         self.add_watch('disable_unused_intervals', self.intervals_changed)
@@ -309,9 +309,9 @@ class AbstractGuitarWidget(gtk.DrawingArea, CairoCommon):
         self.m_neckborder = 6
         self.m_neckl = 0
         self.m_xlist = []
-        self.m_lowest_tone = mpd.int_to_notename(
+        self.m_lowest_tone = mpd.int_to_octave_notename(
             min(map(mpd.notename_to_int, self.m_strings)))
-        self.m_highest_tone = mpd.int_to_notename(
+        self.m_highest_tone = mpd.int_to_octave_notename(
             len(self.m_fretdist) - 1 + max(map(mpd.notename_to_int, self.m_strings)))
         self.m_stringtuning = map(mpd.notename_to_int, self.m_strings)
         tmp = 0
@@ -641,7 +641,7 @@ class AccordionWidget(gtk.DrawingArea, CairoCommon):
                     mark_idx = [m[0] for m in self.m_marks].index(mpd.notename_to_int(notename))
                 except ValueError:
                     mark_idx = -1
-                
+
                 if mark_idx != -1:
                     context.arc(bb + posx + col_idx * self.m_button_xdist + (row_idx+1) % 2 * self.m_button_radius,
                             bb + posy + row_idx * self.m_button_ydist,
