@@ -1,6 +1,6 @@
 # vim: set fileencoding=utf-8 :
 # GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2011  Tom Cato Amundsen
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -39,6 +39,11 @@ import os
 import urllib
 import shutil
 
+try:
+    from pyalsa import alsaseq
+except ImportError:
+    alsaseq = None
+
 from solfege import winlang
 from solfege import buildinfo
 from solfege.esel import FrontPage, TestsView, SearchView
@@ -73,13 +78,12 @@ class SplashWin(gtk.Window):
 
 from solfege.configwindow import ConfigWindow
 from solfege.profilemanager import ChangeProfileDialog
-from solfege.mpd.musicdisplayer import MusicDisplayer
 from solfege import gu
 from solfege import cfg
+from solfege import mpd
 from solfege import stock
 from solfege import lessonfile
-from solfege import lessonfilegui
-from solfege import abstract
+from solfege import download_pyalsa
 from solfege import statistics
 
 
@@ -93,7 +97,7 @@ class MusicViewerWindow(gtk.Dialog):
     def __init__(self):
         gtk.Dialog.__init__(self)
         self.set_default_size(500, 300)
-        self.g_music_displayer = MusicDisplayer()
+        self.g_music_displayer = mpd.MusicDisplayer()
         self.vbox.pack_start(self.g_music_displayer)
         b = gu.bButton(self.action_area, _("Close"), solfege.win.close_musicviewer)
         b.grab_focus()
@@ -231,6 +235,7 @@ class MainWin(gtk.Window, cfg.ConfigUtils):
               self.display_recent_tests),
           ('UserExercises', None, _('_User Exercises'), 'F9', None,
               self.display_user_exercises),
+          ('SetupPyAlsa', None, _("Download and compile ALSA modules"), None, None, self.setup_pyalsa),
           ('HelpHelp', 'gtk-help', _('_Help on the current exercise'), 'F1', None,
             lambda o: solfege.app.please_help_me()),
           ('HelpTheory', None, _('_Music theory on the current exercise'), 'F3', None, lambda o: solfege.app.show_exercise_theory()),
@@ -384,11 +389,11 @@ class MainWin(gtk.Window, cfg.ConfigUtils):
                 gtk.main_iteration(0)
     def show_path_info(self, w):
         if not self.g_path_info_dlg:
-            self.g_path_info_dlg = gtk.Dialog(_("File locations"), self,
+            self.g_path_info_dlg = gtk.Dialog(_("_File locations").replace("_", ""), self,
                 buttons=(gtk.STOCK_OK, gtk.RESPONSE_ACCEPT))
             vbox = gu.hig_dlg_vbox()
             self.g_path_info_dlg.vbox.pack_start(vbox)
-            box1, box2 = gu.hig_category_vbox(_("File locations"))
+            box1, box2 = gu.hig_category_vbox(_("_File locations").replace("_", ""))
             vbox.pack_start(box1)
             sizegroup = gtk.SizeGroup(gtk.SIZE_GROUP_HORIZONTAL)
             # statistics.sqlite
@@ -400,6 +405,7 @@ class MainWin(gtk.Window, cfg.ConfigUtils):
             box2.pack_start(gu.hig_label_widget(_("Solfege installation directory:"), gtk.Label(os.getcwdu()), sizegroup))
             box2.pack_start(gu.hig_label_widget(_("User manual in HTML format:"), gtk.Label(os.path.join(os.getcwdu(), "help")), sizegroup))
             box2.pack_start(gu.hig_label_widget("gtk:", gtk.Label(str(gtk)), sizegroup))
+            box2.pack_start(gu.hig_label_widget("pyalsa:", gtk.Label(str(alsaseq)), sizegroup))
             box2.pack_start(gu.hig_label_widget("PYTHONHOME", gtk.Label(os.environ.get('PYTHONHOME', 'Not defined')), sizegroup))
             self.g_path_info_dlg.show_all()
             def f(*w):
@@ -409,6 +415,8 @@ class MainWin(gtk.Window, cfg.ConfigUtils):
             self.g_path_info_dlg.connect('delete-event', f)
         else:
             self.g_path_info_dlg.show()
+    def setup_pyalsa(self, widget):
+        download_pyalsa.download()
     def show_about_window(self, widget):
         trans = _("SOLFEGETRANSLATORS")
         if trans == 'SOLFEGETRANSLATORS':
@@ -440,13 +448,15 @@ class MainWin(gtk.Window, cfg.ConfigUtils):
         self.g_about_window.destroy()
     def do_tree_editor(self, *v):
         """
-        Open a learning tree editor editing the current front page.
+        Open a front page editor editing the current front page.
         """
         fpeditor.Editor.edit_file(self.get_string("app/frontpage"))
     def post_constructor(self):
         self.m_frontpage_merge_id = None
         self.create_frontpage_menu()
         self.g_ui_manager.add_ui_from_file("help-menu.xml")
+        if sys.platform != 'linux2':
+            self.g_ui_manager.get_widget('/Menubar/HelpMenu/SetupPyAlsa').hide()
         if solfege.app.m_sound_init_exception is not None:
             if solfege.splash_win:
                 solfege.splash_win.destroy()
@@ -482,7 +492,7 @@ class MainWin(gtk.Window, cfg.ConfigUtils):
             winlang.win32_put_langenviron(self.get_string('app/lc_messages'))
         # MIGRATION 3.11.1: earlier editors would create new learning trees
         # below app_data() instead of user_data().
-        if (sys.platform == "win32" and 
+        if (sys.platform == "win32" and
             os.path.exists(os.path.join(filesystem.app_data(),
                                         "learningtrees"))):
             if not os.path.exists(os.path.join(filesystem.user_data(), "learningtrees")):
@@ -546,7 +556,7 @@ class MainWin(gtk.Window, cfg.ConfigUtils):
         else:
             linklist = frontpage.LinkList(os.path.join(filesystem.user_data(), u"exercises", u"user", u"lesson-files"))
             col.insert(0, linklist)
-            
+
         if os.path.isdir(filesystem.user_lessonfiles()):
             linklist = None
             # Added just to be nice with people not moving their files from
